@@ -78,6 +78,93 @@ void Awards::setAwardWAZ(const int _qsoId)
     dataProxy->setWAZAwardStatus(_qsoId);
 }
 
+QString Awards::getQSOofAward (const int _enti, const int _bandid)
+{// Returns the QRZ that granted that status in the DXCC
+    //qDebug() << "Awards::getQSOofAward: " << QString::number(_enti) << "/" << QString::number(_bandid) << endl;
+    QSqlQuery query;
+    QString stringQuery = QString();;
+    bool sqlOK = false;
+    QString answer = QString();
+
+    stringQuery = QString("SELECT call, qso_date, time_on from log where id=(SELECT qsoid from awarddxcc where dxcc='%1' and band='%2')").arg(_enti).arg(_bandid);
+
+    sqlOK = query.exec(stringQuery);
+    //qDebug() << "Awards::getQSOofAward: stringQuery: " << stringQuery << endl;
+    if (sqlOK)
+    {
+        query.next();
+        if (query.isValid())
+        {
+            answer = query.value(0).toString() + " / " + query.value(1).toString() + " / " + query.value(2).toString();
+
+            query.finish();
+            //qDebug() << "Awards::getQSOofAward: answer: " << answer << endl;
+            return answer;
+        }
+        else
+        {
+            query.finish();
+            //qDebug() << "Awards::getQSOofAward: 0" << endl;
+            return QString();
+        }
+    }
+    else
+    {
+        query.finish();
+        emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().number(), query.lastQuery());
+        //qDebug() << "Awards::getQSOofAward: Query error" << endl;
+        return QString();
+    }
+
+}
+
+int Awards::getQSOIdofAward (const int _enti, const int _bandid)
+{// Returns the QSOid that granted that status in the DXCC
+    //qDebug() << "Awards::getQSOIdofAward: " << QString::number(_enti) << "/" << QString::number(_bandid) << endl;
+    QSqlQuery query;
+    QString stringQuery = QString();;
+    bool sqlOK = false;
+    int answer = -1;
+
+    stringQuery = QString("SELECT qsoid from awarddxcc where dxcc='%1' and band='%2'").arg(_enti).arg(_bandid);
+
+    sqlOK = query.exec(stringQuery);
+    //qDebug() << "Awards::getQSOIdofAward: stringQuery: " << stringQuery << endl;
+    if (sqlOK)
+    {
+        query.next();
+        if (query.isValid())
+        {
+            answer = query.value(0).toInt();
+            //qDebug() << "Awards::getQSOIdofAward: answer: " << QString::number(answer) << endl;
+            query.finish();
+            if (answer>=1)
+            {
+                return answer;
+            }
+            else
+            {
+                return -1;
+            }
+
+        }
+        else
+        {
+            query.finish();
+            //qDebug() << "Awards::getQSOIdofAward: 0" << endl;
+            return -2;
+        }
+    }
+    else
+    {
+        query.finish();
+        emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().number(), query.lastQuery());
+        //qDebug() << "Awards::getQSOIdofAward: Query error" << endl;
+        return -3;
+    }
+
+}
+
 int Awards::getDXCCWorked(const int _logNumber)
 {
     //qDebug() << "Awards::getDXCCWorked (logNumber): " << QString::number(_logNumber) << endl;
