@@ -24,7 +24,7 @@
  *****************************************************************************/
 
 #include "contest.h"
-//#include <QDebug>
+#include <QDebug>
 Contest::Contest()
 {
     constrid = 1;
