@@ -24,7 +24,7 @@
  *                                                                           *
  *****************************************************************************/
 
-//#include <QDebug>
+#include <QDebug>
 #include "dataproxy.h"
 
 
@@ -675,7 +675,7 @@ int DataProxy::getHowManyEntities()
     return -1;
 }
 
-int DataProxy::getMaxEntityID()
+int DataProxy::getMaxEntityID(bool limit)
 {
     return -1;
 }
