@@ -46,6 +46,8 @@
 #include "dataproxy_sqlite.h"
 #include "utilities.h"
 
+
+
 enum
 {
     CQZones = 40,
@@ -57,21 +59,25 @@ class FileManager : public QWidget
 {
     Q_OBJECT
 public:
-    FileManager();
-    FileManager(const QString _kontestDir);
-    FileManager(const QString _kontestDir, const QString _softVersion);
+    FileManager(DataProxy *dp);
+    //FileManager(DataProxy *dp, const QString _klogDir);
+    FileManager(DataProxy *dp, const QString _klogDir, const QString _softVersion);
+    //FileManager(DataProxy *dp, const QString _softVersion);
     ~FileManager();
     //bool readAdif(const QString& tfileName, const int logN);
     bool adifReadLog(const QString& tfileName, const int logN);
+    bool adifLoTWReadLog(const QString& tfileName);
+    int adifLoTWLogExport(const QString& _fileName, const int _logN);
     bool adifLogExport(const QString& _fileName, const int _logN);
     bool adifLogExportMarked(const QString& _fileName);
     bool adifReqQSLExport(const QString& _fileName);
-    bool cabrilloLogExport(const QString& _fileName, const int _contestType, const int logNconst);
+    bool cabrilloLogExport(const QString& _fileName, const QString _contestType, const int logNconst);
     bool modifySetupFile(const QString& _filename, QString _field, const QString _value);
+    void setVersion(const QString _version);
 
 
 private:
-    bool adifLogExportToFile(const QString& _fileName, const int _logN, bool justMarked = false, bool _qslRequested = false);
+    bool adifLogExportToFile(const QString& _fileName, const int _logN=0, bool justMarked = false, bool _qslRequested = false, bool _lotw=false);
     bool cabrilloLogExportToFile(const QString& _fileName, const int logNconst);
     bool cabrilloLogExportCQWWToFile(const QString& _fileName, const int logNconst);
     //bool adifCheckMoreThanOneLog(QFile &_f);
@@ -87,10 +93,17 @@ private:
 
     bool checkADIFValidFormat(const QStringList _qs);
 
+    QStringList readAdifField (const QString _field);
+    QString prepareStringLog();
+
+
+    bool dbCreated;
     DataBase *db;
     //float softwareVersion;
-    DataProxy *dataProxy;
-    Utilities *util;
+    //DataProxy_SQLite *dataProxy;
+    DataProxy *dataProxy;//, *dataProxyPrepared;
+
+    Utilities *util;    
 
     bool rstTXDefault, rstRXDefault; // If true and a log is not including RST, 59 is automatically added
 
@@ -98,17 +111,25 @@ private:
     //bool printQs(const QString _q, const QStringList _line);
     bool printQs(const QStringList _line);
     //int confirmed;
-    QString kontestDir;
-    QString kontestVersion;
+    QString klogDir;
+    QString klogVersion;
     //QProgressBar *progressBar;
     bool ignoreUnknownAlways;   // When importing ADIF, ignore all unknown fields.
     bool noMoreQso;
 
     World *world;
     Awards *awards;
+    //QSqlDatabase db;
+
+    QHash<int, int> hashLogs;  // to create different logs when importing a ADIF file
 
     QSqlQuery preparedQuery;
-    QHash<int, int> hashLogs;  // to create different logs when importing a ADIF file
+
+    int constrid; // Just an id for the constructor to check who is being executed at one specific time
+
+
+signals:
+    void queryError(QString functionFailed, QString errorCodeS, int errorCodeN, QString failedQuery); // To alert about any failed query execution
 
 };
 #endif // FILEMANAGER_H
