@@ -507,6 +507,8 @@ qDebug() << "SetupDialog::slotOkButtonClicked" << endl;
         stream << "ShowCallsignInSearch=" << miscPage->getShowStationCallSignInSearch() << ";" <<  endl;
         stream << "KeepMyData=" << miscPage->getKeepMyData() << ";" <<  endl;
         stream << "CompleteWithPrevious=" << miscPage->getCompleteWithPrevious() << ";" <<  endl;
+	stream << "UDPServer=" << miscPage->getUDPServer() << ";" <<  endl;
+        stream << "UDPServerPort=" << miscPage->getUDPServerPort() << ";" <<  endl;
         stream << "CheckNewVersions=" << miscPage->getCheckNewVersions() << ";" <<  endl;
 
         if ((miscPage->getReportInfo()).toUpper() == "TRUE")
@@ -668,11 +670,9 @@ bool SetupDialog::processConfigLine(const QString _line)
     }else if (tab=="CONTEST"){
         //userDataPage->setContest(value);
     }else if (tab=="MODES"){
-        //qDebug() << "SetupDialog::processConfigLine: MODES: " << value << endl;
         readActiveModes(value);
         modes.removeDuplicates();
         bandModePage->setActiveModes(modes);
-        //qDebug() << "SetupDialog::processConfigLine: MODES-2: " << value << endl;
     }else if (tab=="BANDS"){
         readActiveBands(value);
         bands.removeDuplicates();
@@ -710,6 +710,12 @@ bool SetupDialog::processConfigLine(const QString _line)
     else if (tab=="PROVIDEINFO"){
         miscPage->setReportInfo(value);
     }
+    else if (tab=="UDPSERVER"){
+        miscPage->setUDPServer(value);
+    }
+    else if (tab=="UDPSERVERPORT"){
+        miscPage->setUDPServerPort(value);
+    }
     else if (tab =="NAME")
     {
         userDataPage->setName(value);
@@ -906,8 +912,8 @@ void SetupDialog::readActiveModes (const QString actives)
 
     bool atLeastOne = false;
     QStringList _amodes;//, _backModes;
-   // _backModes.clear();
-   // _backModes << modes;
+    // _backModes.clear();
+    // _backModes << modes;
     QStringList values = actives.split(", ", QString::SkipEmptyParts);
     values.removeDuplicates();
 
@@ -928,8 +934,7 @@ void SetupDialog::readActiveModes (const QString actives)
     modes << dataProxy->getModesInLog(-1);
     modes << _amodes;
     modes.removeDuplicates();
-
-    //qDebug() << "SetupDialog::readActiveModes-end: " << modes.join(" / ") << endl;
+    //qDebug() << "SetupDialog::readActiveModes: " << modes.join(" / ") << endl;
 }
 
 bool SetupDialog::isValidBand (const QString b)
@@ -965,6 +970,8 @@ void SetupDialog::setDefaults()
     miscPage->setKeepMyData("TRUE");
     miscPage->setCheckNewVersions("TRUE");
     miscPage->setReportInfo("FALSE");
+    miscPage->setUDPServer("TRUE");
+    miscPage->setUDPServerPort("2237");
 
     dxClusterPage->setShowHFRadiobutton("TRUE");
     dxClusterPage->setShowVHFRadiobutton("TRUE");
