@@ -1207,11 +1207,10 @@ bool World::readCTYCSV(const QString _worldFile)
 
     numberOfEntities = 0; // Reset this variable to reuse it and assign the "dxcc" to the entities (temp solution)
 
-    QSqlQuery query;
-    QSqlQuery queryP;
+    QSqlQuery query;    // Entity information
+    QSqlQuery queryP;   // Prefixes information
 
-    query.prepare("INSERT INTO entity (id, name, cqz, ituz, continent, latitude, longitude, utc, dxcc, mainprefix)"
-                "VALUES (?, ?,?, ?, ?, ?, ?, ?, ?, ?)");
+    query.prepare("INSERT INTO entity (id, name, cqz, ituz, continent, latitude, longitude, utc, dxcc, mainprefix) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?)");
     queryP.prepare("INSERT INTO prefixesofentity (id, prefix, dxcc, cqz, ituz) VALUES (?, ?, ?, ?, ?)");
 
     QSqlDatabase::database().transaction();
@@ -1235,9 +1234,9 @@ bool World::readCTYCSV(const QString _worldFile)
 //    0        1        2      3      4    5     6     7      8       9
 
         tq = file.readLine();
-       //qDebug()  << "World::readCTYCSV(): Line: " << tq << endl;
+        //qDebug()  << "World::readCTYCSV(): Line: " << tq << endl;
         tq = tq.simplified();
-       //qDebug()  << "World::readCTYCSV(): Line simplified: " << tq << endl;
+        //qDebug()  << "World::readCTYCSV(): Line simplified: " << tq << endl;
         tq = tq.trimmed();
        //qDebug()  << "World::readCTYCSV(): Line trimmed: " << tq << endl;
         tq.remove(QChar(';'), Qt::CaseInsensitive);
@@ -1245,10 +1244,12 @@ bool World::readCTYCSV(const QString _worldFile)
 
         stringList << tq.split(',');
 
-       //qDebug()  << "World::readCTYCSV(): Line stringList-0: " << stringList.at(0) << endl;
+        //qDebug()  << "World::readCTYCSV(): Line stringList-0: " << stringList.at(0) << endl;
 
         if (( stringList.at(0)).contains(QChar('*'), Qt::CaseInsensitive))
-        {
+        { // This is a special Entity. Not really an ARRL Entity but interesting for the DXer.
+          // From http://www.country-files.com/cty-dat-format
+          // (A “*” preceding this prefix indicates that the country is on the DARC WAEDC list, and counts in CQ-sponsored contests, but not ARRL-sponsored contests).
             entN = -1;
             entN = (stringList.at(2)).toInt() + 1000;
 
@@ -1267,6 +1268,7 @@ bool World::readCTYCSV(const QString _worldFile)
             entityNumber = stringList.at(2);
         }
 
+        //qDebug()  << "World::readCTYCSV(): Line stringList Length: " << QString::number(stringList.length()) << endl;
 
         if (stringList.size()>=8 )
         {
@@ -1298,14 +1300,16 @@ bool World::readCTYCSV(const QString _worldFile)
 
             if (query.exec())
             {
-                //qDebug()  << "World::readCTYDAT(): Entity data added"  << endl;
+                //qDebug()  << "World::readCTYDAT(): Entity data added: " <<  stringList.at(1)  << endl;
             }
-            else if (errorCode == 19)
+            else if (query.lastError().number() == 19)
             {
+                //qDebug()  << "World::readCTYDAT(): Entity data added: error19:  " <<  stringList.at(1)  << endl;
                 emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().number(), query.lastQuery());
             }
             else
             {
+                //qDebug()  << "World::readCTYDAT(): Entity data added: error else:  " <<  stringList.at(1)  << endl;
                 emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().number(), query.lastQuery());
                 errorCode = query.lastError().number();
 
@@ -1318,6 +1322,7 @@ bool World::readCTYCSV(const QString _worldFile)
 
             }
 
+             //qDebug()  << "World::readCTYCSV(): Entity ADDED or NOT"  << endl;
             if (stringList.size()>8)
             {
                 tq = stringList.at(9);
@@ -1360,12 +1365,13 @@ bool World::readCTYCSV(const QString _worldFile)
                     {
                         //qDebug()  << "World::readCTYCSV(): Prefix added: " << stringListPrefixes.at(i) << endl;
                     }
-                    else if (errorCode == 19)
+                    else if (queryP.lastError().number() == 19)
                     {}
                     else
                     {
-                        emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().number(), query.lastQuery());
-                        errorCode = query.lastError().number();
+                        errorCode = queryP.lastError().number();
+                        emit queryError(Q_FUNC_INFO, queryP.lastError().databaseText(), queryP.lastError().number(), queryP.lastQuery());
+
 
                        //qDebug() << "World::readCTYCSV(): Prefix data NOT added"  << endl;
                        //qDebug() << "World::readCTYCSV(): Prefix LastQuery: " << query.lastQuery()  << endl;
